def add_number(num1, num2):
    return num1 + num2

def sub_number(num1, num2):
    return num1 - num2

def div_number(num1, num2):
    return num1 / num2

def multi_number(num1, num2):
    return num1 * num2